//******************************************************************************
//
//
//     INDICADOR DE CARGA DE BATERIA VEICULAR COM 3 LEDS 
//
//
//
//    OBJETIVO:  INDICADOR DE SITUAO DA CARGA DO ALTERNADOR DO VEICULO USANDO
//    3 LEDS E UM PIC 12F675.
//    TRATA-SE DE UM TESTADOR PORTATIL PARA MECANICOS E ELETRICISTA DE AUTOS, 
//    PERMITINDO UMA AVALIAO RPIDA DO FUNCIONAMENTO DO ALTERNADOR DO VEICULO.
//
//    AUTOR: CLUDIO LRIOS     DATA:12/02/2014
//    
//    MODO DE OPERAO: CONECTE O INDICADOR DIRETAMENTE NOS TERMINAIS DA BATERIA
//    DE 12 VOLTS DO VEICULO (USE 2 GARRINHAS 'JACAR' NAS PONTAS P/ FACILITAR).
//
//    LEITURA DA TENSO DA BATERIA PELO ACENDIMENTO DOS LEDS, SENDO:
//    LED VERMELHO PISCANDO = TENSO  ABAIXO DE 10 VOLTS (NO EST 'CARREGANDO')
//    LED VERMELHO ACESO  = TENSO  ENTRE 11,5 V E 10 V. (NO EST 'CARREGANDO')
//    LED AMARELO ACESO = TENSO ENTRE 13,5 V A 11,5 V. (CARGA DEFICIENTE)
//    LED VERDE ACESO = TENSO ENTRE 13,5 A 15 V. (CARREGANDO CORRETAMENTE)
//    LED VERDE PISCANDO = TENSO ACIMA DE 15 V. (SOBRECARGA NO ALTERNADOR)
//
//
//    PINAGEM DE LIGAO DO PIC 12F675:
//    PINO 1= VCC (+5V)
//    PINO 2= RESISTOR 470 OHMS AO LED VERMELHO E  DESTE P/ O GND.
//    PINO 3= RESISTOR 470 OHMS AO LED AMARELHO E  DESTE P/ O GND.
//    PINO 4= DESLIGADO
//    PINO 5= CENTRO DO TRIMER DE 4K7, C/ EXTREMO ESQ. AO GND E EXTREMO DIREITO
//            A UM RESISTOR DE 10K A ENTRADA DE 12 VOLTS DIRETA DA BATERIA
//            A MEDIR
//    PINO 6= RESISTOR 470 OHMS AO LED VERDE E  DESTE P/ O GND.
//    PINO 7= DESLIGADO
//    PINO 8= GND.
//    
//    CALIBRAO INICIAL:
//    LIGUE UM FONTE REGULAVEL DE 0-20 VOLTS NO EQUIPAMENTO, SIMULANDO A BATERIA
//    AJUSTE A FONTE PARA OBTER 15 VOLTS NA SADA.
//    AJUSTE O TRIMPOT DE 4K7 PARA COMEAR A PISCAR O LED VERDE NESTE TENSO.
//    CONFIRA, POR ABAIXAR A TENSO DA FONTE E AUMENTA-LA GRADATIVAMENTE, SEMPRE
//    OBSERVANDO A MUDANA DO LED VERDE DE 'ACESO' PARA 'PISCANDO'.
//    
//    OBS. MONTAGEM APENAS DIDTICA
//    USE CCS COMPILER.
//
//******************************************************************************


//==============================================================================
//Descomente o abaixo SOMENTE se perdeu o byte de calibrao

//    #define PERDI_BYTE_CALIBRACAO   // PROVIDENCIA BYTE PROVISRIO PARA TESTE
//==============================================================================


#include <12F675.h>
#device adc=8
#use delay(clock=4000000)
#fuses NOWDT,INTRC_IO, NOCPD, NOPROTECT, NOMCLR, PUT, BROWNOUT
#use fast_io(A)  //  sentido das portas feita pelo programador
#ifdef  PERDI_BYTE_CALIBRACAO  // calibrao do oscilador interno do pic
#ROM  0X3FF = {0X34fc}//mxima freq= 0x34fc ;mdia=0x3480; minima=0x3400
#endif
#ZERO_RAM

//==============================================================================
//   REGISTRADORES
//==============================================================================
#byte gpio   = 0x05
#byte tmr0   = 0x01
#byte tris   = 0x85
#byte t1con   =0x10
#byte tmr1h   =0x0f
#byte tmr1l   =0x0e
#byte pir1    =0x0c
#byte tmr1h   =0x0f
#byte tmr1l   =0x0e
#byte intcon  =0x8b
#byte status  =0x03
//==============================================================================
//   DEFINIO DE PINOS E SAIDAS
//==============================================================================
#bit  VD    = 0x5.1 //pino 6
#bit  AM    = 0x5.4 //pino 3
#bit  VM    = 0x5.5 //pino 2

int valor;
short pisca;
//==============================================================================
//               rotina main
//==============================================================================
Void Main (){
      tris=0b001101; //direo das portas
      setup_comparator(NC_NC_NC_NC);// desliga comparadores analgicos
      setup_adc_ports(sAN2 | VSS_VDD);  //seleciona AN2 e 5v como referncia
      setup_adc(ADC_CLOCK_DIV_8 );// ajusta o clock do adc
      set_adc_channel(2); //ajusta para o pino 5 (AN2)
      delay_us(10); //delay
//==============================================================================
//       loop principal

   While (true) {


    valor = READ_ADC();// l valor da tenso de entrada do pino 5
    gpio=0;//desliga ports

   // caso deseje outras indicaes, altere as constantes aps 'valor>'
     if(valor> 125) pisca=1; //pisca led verde (acima de 15v)
     if(valor> 110){ vd=1;am=0; vm=0;}//liga led verde sem piscar acima de 13,5v
     else {
      if(valor> 95){ am=1; vd=0; vm=0;}//liga led amarelo entre 11,5 v a 13,5v
       else {
        if(valor> 85) { vm=1; vd=0; am=0;}//liga led vermelho entre 11,5v e 10 v
        else {vm=1; vd=0; am=0; pisca=1;}//pisca led vermelho abaixo de 10 v
        }
     }
 
    if (pisca){// verifica se dever piscar o led verde ou vermelho
     pisca=0;// piscar
     delay_ms(300);
     gpio=0;
     delay_ms(300);     
    }
    else {
     delay_ms(100);  // no piscar , mas dar um breve atraso entre leituras
     }


   }//   WHILE (TRUE)
}//VOID MAIN













